#!/bin/bash

# release locations
GLOBAL_RELEASE_DIR=/common/usr/cscofe/silecs

function help {
    echo -e ""
    echo -e "Script in order to build and install the complete silecs framework"
    echo -e ""
    echo -e "Usage:"
    echo -e ""
    echo -e "\t Install version 1.2.3 to default directory ($GLOBAL_RELEASE_DIR):"
    echo -e "\t\t ./releaseSilecs.sh 1.2.3"
    echo -e ""
    echo -e "\t Install version 1.2.3 to custom directory:"
    echo -e "\t\t ./releaseSilecs.sh 1.2.3 /home/user/MyCustomDir"
    echo -e ""
    exit 1;
}

if [ $# -lt 1 ]
  then
    echo "Error: Wrong number of arguments supplied."
    help
fi

if [[ "$1" == "-h" || "$1" == "--help" ]];
then
    help
fi

# List of silecs packages which can be released
PACKAGES="silecs-codegen silecs-model snap7 silecs-communication-cpp silecs-diagnostic-cpp silecs-cli silecs-cli-client"

SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")     # path where this script is located in

# Used in makefile for silecs-communication
exportVersionInfo()
{
    VERSION=$1
    MAJOR=`echo $VERSION | cut -d. -f1`
    MINOR=`echo $VERSION | cut -d. -f2`
    PATCH=`echo $VERSION | cut -d. -f3`
    export MAJOR=${MAJOR}
    export MINOR=${MINOR}
    export PATCH=${PATCH}
}

# Check that folder exists, print proper error if not
checkFolderExists()
{
    FOLDER=$1
    if [ ! -d ${FOLDER} ]; then
        echo "Error: The folder '${FOLDER}' is needed in order to finish the installation."
        echo "Installation cancelled."
        return 1
    fi
}

VERSION=$1

if ["$2" ]
  then
    RELEASE_DIR_BASE=$2
  else
    RELEASE_DIR_BASE=$GLOBAL_RELEASE_DIR
fi

exportVersionInfo ${VERSION}

for PACKAGE in $PACKAGES; do
    INSTALL_DIR=${RELEASE_DIR_BASE}/${PACKAGE}/${VERSION}
    if [ -d ${INSTALL_DIR} ]; then 
        echo "Warning: Silecs version ${VERSION} is already installed in ${INSTALL_DIR} ... skipping."
    else
        checkFolderExists ${PACKAGE}
        echo "installing ${INSTALL_DIR} from ${PACKAGE}"
        ${PACKAGE}/install.sh ${INSTALL_DIR}
        if [ "$?" -eq "1" ]; then
            echo "Installation cancelled."
            exit 1
        fi
    fi
done

exit 0
